@@ -20,6 +20,7 @@
 
 #include <glib/gi18n.h>
 #include <gnome-todo.h>
+#include <math.h>
 
 struct _GtdPanelScheduled
 {
@@ -54,24 +55,32 @@ static gchar*
 get_string_for_date (GDateTime *dt,
                      gint      *span)
 {
+  GDateTime *today;
+  GDateTime *next_year;
   GDateTime *now;
   gchar *str;
   gint days_diff;
+  gint next_year_diff;
 
   /* This case should never happen */
   if (!dt)
     return g_strdup (_("No date set"));
 
-  now = g_date_time_new_now_local ();
-  days_diff = g_date_time_difference (dt, now) / G_TIME_SPAN_DAY;
+  now = g_date_time_new_now_utc ();
+  today = g_date_time_new_utc (g_date_time_get_year (now),
+                               g_date_time_get_month (now),
+                               g_date_time_get_day_of_month (now),
+                               0, 0, 0);
+  next_year = g_date_time_new_utc (g_date_time_get_year (now) + 1,
+                                   G_DATE_JANUARY,
+                                   1,
+                                   0, 0, 0);
+  next_year_diff = g_date_time_difference (next_year, today) / G_TIME_SPAN_DAY;
+  days_diff = g_date_time_difference (dt, today) / G_TIME_SPAN_DAY;
 
-  if (days_diff < -1)
+  if (days_diff < 0)
     {
-      str = g_strdup_printf (_("%d days ago"), -days_diff);
-    }
-  else if (days_diff == -1)
-    {
-      str = g_strdup (_("Yesterday"));
+      str = g_strdup_printf (g_dngettext (NULL, "Yesterday", "%d days ago", -days_diff), -days_diff);
     }
   else if (days_diff == 0)
     {
@@ -85,7 +94,7 @@ get_string_for_date (GDateTime *dt,
     {
       str = g_date_time_format (dt, "%A"); // Weekday name
     }
-  else if (days_diff >= 7 && days_diff < (365 + g_date_time_get_year (dt) % 4 == 0))
+  else if (days_diff >= 7 && days_diff < next_year_diff)
     {
       str = g_date_time_format (dt, "%B"); // Full month name
     }
@@ -97,6 +106,8 @@ get_string_for_date (GDateTime *dt,
   if (span)
     *span = days_diff;
 
+  g_clear_pointer (&next_year, g_date_time_unref);
+  g_clear_pointer (&today, g_date_time_unref);
   g_clear_pointer (&now, g_date_time_unref);
 
   return str;
@@ -185,6 +196,54 @@ gtd_panel_scheduled_header_func (GtkListBoxRow     *row,
   g_clear_pointer (&dt, g_date_time_unref);
 }
 
+static gint
+gtd_panel_scheduled_sort_func (GtkListBoxRow     *row1,
+                               GtdTask           *row1_task,
+                               GtkListBoxRow     *row2,
+                               GtdTask           *row2_task,
+                               GtdPanelScheduled *panel)
+{
+  GDateTime *dt1;
+  GDateTime *dt2;
+  gint retval;
+  gchar *t1;
+  gchar *t2;
+
+  dt1 = dt2 = NULL;
+
+  if (row1_task)
+    dt1 = gtd_task_get_due_date (row1_task);
+  if (row2_task)
+    dt2 = gtd_task_get_due_date (row2_task);
+
+  if (!dt1 && !dt2)
+    retval = 0;
+  else if (!dt1)
+    retval = 1;
+  else if (!dt2)
+    retval = -1;
+  else
+    retval = g_date_time_compare (dt1, dt2);
+
+  g_clear_pointer (&dt1, g_date_time_unref);
+  g_clear_pointer (&dt2, g_date_time_unref);
+
+  if (retval != 0)
+    return retval;
+
+  t1 = t2 = NULL;
+
+  t1 = g_utf8_casefold (gtd_task_get_title (row1_task), -1);
+  t2 = g_utf8_casefold (gtd_task_get_title (row2_task), -1);
+
+  retval = g_strcmp0 (t1, t2);
+
+  g_free (t1);
+  g_free (t2);
+
+  return retval;
+}
+
 static void
 gtd_panel_scheduled_clear (GtdPanelScheduled *panel)
 {
@@ -413,6 +472,10 @@ gtd_panel_scheduled_init (GtdPanelScheduled *self)
                                       (GtdTaskListViewHeaderFunc) gtd_panel_scheduled_header_func,
                                       self);
 
+  gtd_task_list_view_set_sort_func (GTD_TASK_LIST_VIEW (self->view),
+                                    (GtdTaskListViewSortFunc) gtd_panel_scheduled_sort_func,
+                                    self);
+
   gtk_widget_show_all (GTK_WIDGET (self));
 }
 
