@@ -92,8 +92,9 @@ gtd_application_show_about (GSimpleAction *simple,
   int created_year = 2015;
 
   static const gchar *authors[] = {
-    "Georges Basile Stavracas Neto <georges.stavracas@gmail.com>",
     "Emmanuele Bassi <ebassi@gnome.org>",
+    "Georges Basile Stavracas Neto <georges.stavracas@gmail.com>",
+    "Patrick Griffis <tingping@tingping.se>",
     NULL
   };
 
@@ -123,7 +124,7 @@ gtd_application_show_about (GSimpleAction *simple,
                          "license-type", GTK_LICENSE_GPL_3_0,
                          "authors", authors,
                          "artists", artists,
-                         "logo-icon-name", "gnome-todo",
+                         "logo-icon-name", "org.gnome.Todo",
                          "translator-credits", _("translator-credits"),
                          NULL);
   g_free (copyright);
