@@ -23,8 +23,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <math.h>
-
 typedef struct
 {
   GtkRevealer               *revealer;
@@ -39,6 +37,7 @@ typedef struct
   GtkEntry                  *title_entry;
   GtkLabel                  *task_date_label;
   GtkLabel                  *task_list_label;
+  GtkStack                  *task_stack;
   GtkSpinner                *task_loading_spinner;
   GtkLabel                  *title_label;
 
@@ -81,13 +80,11 @@ gtd_task_row__priority_changed_cb (GtdTaskRow *row,
                                    GParamSpec *spec,
                                    GObject    *object)
 {
-  GtdTaskRowPrivate *priv;
   GtkStyleContext *context;
   gint priority;
 
   g_return_if_fail (GTD_IS_TASK_ROW (row));
 
-  priv = row->priv;
   context = gtk_widget_get_style_context (GTK_WIDGET (row));
   priority = gtd_task_get_priority (GTD_TASK (object));
 
@@ -124,13 +121,11 @@ gtd_task_row__date_changed_binding (GBinding     *binding,
                                     GValue       *to_value,
                                     gpointer      user_data)
 {
-  GtdTaskRowPrivate *priv;
   GDateTime *dt;
   gchar *new_label = NULL;
 
   g_return_val_if_fail (GTD_IS_TASK_ROW (user_data), FALSE);
 
-  priv = GTD_TASK_ROW (user_data)->priv;
   dt = g_value_get_boxed (from_value);
 
   if (dt)
@@ -211,9 +206,9 @@ gtd_task_row__entry_focus_out (GtkWidget     *widget,
   g_return_val_if_fail (GTD_IS_TASK_ROW (user_data), FALSE);
 
   if (priv->new_task_mode)
-    {
-      gtk_stack_set_visible_child_name (priv->new_task_stack, "label");
-    }
+    gtk_stack_set_visible_child_name (priv->new_task_stack, "label");
+  else
+    gtk_stack_set_visible_child_name (priv->task_stack, "label");
 
   return FALSE;
 }
@@ -231,6 +226,11 @@ gtd_task_row__focus_in (GtkWidget *widget,
       gtk_stack_set_visible_child_name (priv->new_task_stack, "entry");
       gtk_widget_grab_focus (GTK_WIDGET (priv->new_task_entry));
     }
+  else
+    {
+      gtk_stack_set_visible_child_name (priv->task_stack, "title");
+      gtk_widget_grab_focus (GTK_WIDGET (priv->title_entry));
+    }
 
   return FALSE;
 }
@@ -287,9 +287,6 @@ gtd_task_row__entry_activated (GtkEntry *entry,
 static void
 gtd_task_row_finalize (GObject *object)
 {
-  GtdTaskRow *self = (GtdTaskRow *)object;
-  GtdTaskRowPrivate *priv = gtd_task_row_get_instance_private (self);
-
   G_OBJECT_CLASS (gtd_task_row_parent_class)->finalize (object);
 }
 
@@ -372,8 +369,8 @@ gtd_task_row_class_init (GtdTaskRowClass *klass)
           object_class,
           PROP_NEW_TASK_MODE,
           g_param_spec_boolean ("new-task-mode",
-                                _("If the row is used to add a new task"),
-                                _("Whether the row is used to add a new task"),
+                                "If the row is used to add a new task",
+                                "Whether the row is used to add a new task",
                                 FALSE,
                                 G_PARAM_READWRITE));
 
@@ -386,8 +383,8 @@ gtd_task_row_class_init (GtdTaskRowClass *klass)
           object_class,
           PROP_TASK,
           g_param_spec_object ("task",
-                               _("Task of the row"),
-                               _("The task that this row represents"),
+                               "Task of the row",
+                               "The task that this row represents",
                                GTD_TYPE_TASK,
                                G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -461,12 +458,15 @@ gtd_task_row_class_init (GtdTaskRowClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, revealer);
   gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, task_date_label);
   gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, task_list_label);
+  gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, task_stack);
   gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, task_loading_spinner);
   gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, title_entry);
   gtk_widget_class_bind_template_child_private (widget_class, GtdTaskRow, title_label);
 
   gtk_widget_class_bind_template_callback (widget_class, gtd_task_row__entry_activated);
   gtk_widget_class_bind_template_callback (widget_class, gtd_task_row__entry_focus_out);
+
+  gtk_widget_class_set_css_name (widget_class, "task-row");
 }
 
 static void
@@ -558,16 +558,32 @@ void
 gtd_task_row_set_task (GtdTaskRow *row,
                        GtdTask    *task)
 {
+  GtdTaskRowPrivate *priv;
+
   g_return_if_fail (GTD_IS_TASK_ROW (row));
 
+  priv = row->priv;
+
   if (row->priv->task != task)
     {
       row->priv->task = task;
 
       if (task)
         {
-          gtk_entry_set_text (row->priv->title_entry, gtd_task_get_title (task));
           gtk_label_set_label (row->priv->task_list_label, gtd_task_list_get_name (gtd_task_get_list (task)));
+
+          g_object_bind_property (task,
+                                  "title",
+                                  priv->title_entry,
+                                  "text",
+                                  G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+
+          g_object_bind_property (task,
+                                  "title",
+                                  priv->title_label,
+                                  "label",
+                                  G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+
           g_object_bind_property (task,
                                   "complete",
                                   row->priv->done_check,
@@ -576,13 +592,13 @@ gtd_task_row_set_task (GtdTaskRow *row,
 
           g_object_bind_property (task,
                                   "ready",
-                                  row->priv->task_loading_spinner,
+                                  priv->task_loading_spinner,
                                   "visible",
                                   G_BINDING_INVERT_BOOLEAN | G_BINDING_SYNC_CREATE);
 
           g_object_bind_property_full (task,
                                        "due-date",
-                                       row->priv->task_date_label,
+                                       priv->task_date_label,
                                        "label",
                                        G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE,
                                        gtd_task_row__date_changed_binding,
